brain-indexer
=============

.. note::

   We would like this documentation to be useful for all our users. Therefore,
   if you spot any missing content or inconsistencies, please contact us and
   we'll fix it.

The documentation of brain-indexer contains the following sections:

.. toctree::
   :maxdepth: 1

   Introduction <intro>
   Installation <installation>
   Queries <queries>
   Insert Elements <insertion>
   Overlap Detection Details <accuracy>
   Multi Index <multi_index>
   Multiple Populations <multi_population>
   Morphology and Synapse Conventions <conventions>
   Performance Tricks <performance_tricks>
   Developer Guide <developer_guide>
   Change Log <CHANGES>
   Python API Reference<api>

